import java.util.Scanner;

/*
  Author:  James Tam
  Version: January 21, 2011

  (January 21 2011): The array of references to books has been changed to a linked
  list implimentation.

  (Feb 3 2010): Replaced input routines that were implemented with classes from the 
  tio package with the standard Java Scanner class.

  This class performs list management functions for an array of references to Foo:
  * Displaying the list.
  * Adding elements to the end of the list.
  * Deleting elements from the end of the list.
*/

public class Manager
{  
    private BookNode head;
    /*
      The no-argument constructor only initializes the head pointer, no memory
      needs to be allocated yet.
     */
    public Manager ()
    {
       head = null;
    }

    /*
      This method iterates through the array and display the data value for each
      Book or an error message if the list is empty.
     */
    public void display()
    {
	int i = 1;
      BookNode temp = head;
	System.out.println("Displaying list");
	if (head == null)
	    System.out.println("\tList is empty");
	while (temp != null)
	{
	    System.out.println("\tTitle No. " + i + ": "+ temp.getData().getName());
          i = i + 1;
          temp = temp.getNext();
	}
    }
    
    /*
      This method adds a new element to the end of list until the list is full 
      (current maximum capacity of 10 elements)
     */
    public void add ()
    {
	System.out.print("Enter a title for the book: ");
	Scanner in = new Scanner(System.in);
      String newName = in.nextLine();
      Book aBook = new Book (newName);
      BookNode aBookNode = new BookNode(aBook,null);
      if (head == null)
         head = aBookNode;
      else
      {
         BookNode current = head;
         BookNode previous = null;   
         while (current != null)
         {
           previous = current;
           current = current.getNext();
         }
         previous.setNext(aBookNode);
      }
    }

    /*
      This method will remove the last element from the list or an error message if
      the list is already empty.
     */
    public void remove ()
    {
      // Case 1: Empty list
	if (head == null)
	{
	    System.out.println("List is already empty: Nothing to remove");
	}
      // Case 2: Non-empty list   
	else
	{
         BookNode previous = null;
         BookNode current = head;
         String searchName = null;
         boolean isFound = false;
         String currentName;
         Scanner in = new Scanner(System.in);
         System.out.print("Enter name of book to remove: ");
         searchName = in.nextLine();      

         while ((current != null) &&
                (isFound == false))
         {
           currentName = current.getData().getName();
           if (searchName.compareToIgnoreCase(currentName) == 0)
              isFound = true;
           else
           {
              previous = current;
              current = current.getNext();
           }
         }

    
         // Case 2A or Case 2B: Match found, remove a node         
         if (isFound == true)
         {
            System.out.println("Removing book called " + searchName);
            // Case 2A: Remove the first node
            if (previous == null)
               head = head.getNext();
            // Case 2B: Remove any node except for the first
            else
               previous.setNext(current.getNext());
         }
         // Case 3: Entire list searched, no match found - nothing to remove.
         else
         {
            System.out.println("No book called " + searchName + " in the collection.");
    
         }
	}
    }

    /*public boolean search (BookNode previous,
                           BookNode current,
                           String searchName)
    {
         boolean isFound = false;

            
         while ((current != null) &&
                (isFound == false))
         {
           currentName = current.getData().getName();
           if (searchName.compareToIgnoreCase(currentName) == 0)
              isFound = true;
           else
           {
              previous = current;
              current = current.getNext();
           }
         }

         if (current != null)
            System.out.println(current.getData().getName());
         if (previous != null)
            System.out.println(previous.getData().getName());
         return isFound;

    }
      */                    
                     
}
